@@ -5,10 +5,11 @@ use IM::Engine;
 
 has engine => (
     is       => 'ro',
-    writer   => '_set_engine',
     isa      => 'IM::Engine',
     weak_ref => 1,
 );
 
+no Moose::Role;
+
 1;
 
